@@ -11,6 +11,7 @@ from tipg.database import close_db_connection, connect_to_db
 from tipg.errors import DEFAULT_STATUS_CODES, add_exception_handlers
 from tipg.factory import Endpoints
 from tipg.middleware import CacheControlMiddleware, CatalogUpdateMiddleware
+from tipg.openapi import _update_openapi
 from tipg.settings import APISettings, CustomSQLSettings, DatabaseSettings
 
 from fastapi import FastAPI, Request
@@ -53,6 +54,9 @@ app = FastAPI(
     root_path=settings.root_path,
 )
 
+# Fix OpenAPI response header for OGC Common compatibility
+_update_openapi(app)
+
 # custom template directory
 templates_location: List[Any] = (
     [jinja2.FileSystemLoader(settings.template_directory)]
@@ -90,7 +94,7 @@ if settings.catalog_ttl:
         CatalogUpdateMiddleware,
         func=register_collection_catalog,
         ttl=settings.catalog_ttl,
-        dg_settings=db_settings,
+        db_settings=db_settings,
     )
 
 add_exception_handlers(app, DEFAULT_STATUS_CODES)
